OperatingSystem class final

The name and version of an operating system.

Constructors

OperatingSystem(String id, String version)
Creates a new operating system object for testing.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
A string representing the operating system or platform.
no setter
isAndroid → bool
Whether the operating system is a version of Android.
no setter
isBrowser → bool
Whether running in a web browser.
no setter
isFuchsia → bool
Whether the operating system is a version of Fuchsia.
no setter
isIOS → bool
Whether the operating system is a version of iOS.
no setter
isLinux → bool
Whether the operating system is a version of Linux.
no setter
isMacOS → bool
Whether the operating system is a version of macOS.
no setter
isWindows → bool
Whether the operating system is a version of Microsoft Windows.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
A string representing the version of the operating system or platform.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current → OperatingSystem
The current operating system ID.
no setter

Constants

androidId → const String
The operating system ID string for Linux.
browserId → const String
The operating system ID string for browsers.
fuchsiaId → const String
The operating system ID string for Fuchsia.
iOSId → const String
The operating system ID string for iOS.
linuxId → const String
The operating system ID string for Linux.
macOSId → const String
The operating system ID string for macOS.
windowsId → const String
The operating system ID string for Windows.